#!/bin/sh
#
# RedHat Linux Dial in Server Configuration script
# Version 2.0
#
# Author : Jiju Thomas Mathew (jthoma@md2.vsnl.net.in)

if [ ! "$EUID" = "0" ]; then
   echo "Sorry, you must be logged in as root (or run 'su -') to run this program"
   echo
   exit 1
fi

THISHOST="`hostname -f`"
SHORTIP="`hostname -i|awk -F. '{print $1"."$2"."$3"."}'`"

if [ ! -x $(which dialog) ] ; then
   echo One moment please...
   rpm -ivh --force /mnt/cdrom/RedHat/RPMS/dialog*.rpm
fi

tmpfile=`mktemp /tmp/temp.XXXXXX`
dialog --clear --title "Welcome to the installer"\
	--backtitle "RedHat Linux Dial in Server Configuration script Version 2.0"\
	--textbox "readme.txt" 22 77

dialog --backtitle "RedHat Linux Dial in Server Configuration script Version 2.0"\
	--menu "Choose Install Type" 10 50 3 \
		1 'Test install' 2 'Actual Install'\
		3 'Cancel and Exit' 2> $tmpfile
ITYPE=`cat $tmpfile`
# The prerequesites are over and we are into the second stage
case $ITYPE in
	1)
	  #test install
		INSTROOTetc="/tmp/etc"
		INSTROOTbin="/tmp/bin"
		instaltyp="Test"
                FINISHMSG="\nYou did a test install. Check all the files\nand do an actual install if you want"
                TITLE="-  Testing"
	  if [ ! -e $INSTROOTetc ] ; then
    		mkdir $INSTROOTetc
		cp /etc/inittab $INSTROOTetc/inittab
		mkdir $INSTROOTetc/ppp
                cp /etc/ppp/options $INSTROOTetc/ppp/options
	    	mkdir $INSTROOTetc/mgetty+sendfax
		cp /etc/mgetty+sendfax/login.config $INSTROOTetc/mgetty+sendfax
    		mkdir $INSTROOTbin
	  fi
	;;
	2)
	  # Actual install
		INSTROOTetc="/etc"
		INSTROOTbin="/bin"
		instaltyp="Actual"
		TITLE=" "
                FINISHMSG="\nCongratulations!\nYou have completed the Actual Install"
	;;
	3)
	  # user asked for exit
		exit 100
	;;
esac

# find out the modem port, better ask and make sure
dialog --backtitle "RedHat Linux Dial in Server Configuration script Version 2.0   $TITLE"\
	--menu "Choose modem port" 12 50 4 \
		ttyS0 'Com 1' ttyS1 'Com 2'\
		ttyS2 'Com 3' ttyS3 'Com 4' 2> $tmpfile

COMPORT=`cat $tmpfile`


# we have the comport too now we need an unused ip address
# being straight forward, it is polite to ask for one
	dialog --backtitle "RedHat Linux Dial in Server Configuration script Version 2.0   $TITLE"\
		--inputbox "We need one unused IP address from your\nnetwork to assign to the remote machine,\nplease enter one"\
		10 50 $SHORTIP 2> $tmpfile

REMOTEIP=`cat $tmpfile`


# now the inevitable, get the DNS address

nslookup "`hostname -f`" > $tmpfile
cat $tmpfile | while read md ; do
  case $md in
     Address*)
       mf=`echo $md | awk -F ": " '{print $2}'`
       echo "$mf" > $tmpfile 
       ;;
     *)
       echo "$md" > /dev/null
       ;;
  esac
done
DNSSERV="`cat $tmpfile`"

if [ ! $DNSSERV ] ; then
#-- did not get DNS address so ask for it
	dialog --backtitle "RedHat Linux Dial in Server Configuration script Version 2.0   $TITLE"\
		--inputbox "We need the DNS Server IP address from your\nnetwork to assign to the remote machine,\nplease enter it"\
		10 50 $SHORTIP 2> $tmpfile

DNSSERV="`cat $tmpfile`"
fi
rm -f $tmpfile

# now that we got all info we need, we start the job
#----------------------------------------------------
# back up current config

if [ ! -f $INSTROOTetc/inittab.out ] ; then
	cp $INSTROOTetc/inittab $INSTROOTetc/inittab.out
	cp $INSTROOTetc/inittab $INSTROOTetc/inittab.in
else
	cp $INSTROOTetc/inittab.out $INSTROOTetc/inittab.in
fi

# ask wether he wishes to have delay dial or not

dialog 	--backtitle "RedHat Linux Dial in Server Configuration script Version 2.0" --title "Configure Delay dial ?" --yesno "The modem can be enabled with a delay dial; that is:\nthe first ring will be ignored, but a second ring after\natleast 10 seconds before 45 seconds will be attended,\nthis may be useful if you are at your office and you\nwant to leave the attend mode on, but you are short of\ntelephone lines. Choosing yes enables this mode, and\nchoosing no will disable this mode (the modem will\nattend at first ring)" 14 70	

case $? in
   0)  
   INITS="V1:2345:respawn:/sbin/mgetty -R 45 -s 115200 $COMPORT"
   ;;
   1)
   INITS="V1:2345:respawn:/sbin/mgetty -s 115200 $COMPORT"
   ;;
esac

dialog --infobox 'Configuring ...!' 3 40

echo "" >> $INSTROOTetc/inittab.in
echo "# Run mgetty to trap incoming calls" >> $INSTROOTetc/inittab.in
echo "# added by Dial in script by jthoma@md2.vsnl.net.in" >> $INSTROOTetc/inittab.in
echo "$INITS" >> $INSTROOTetc/inittab.in

#-----edit the login.config file to enable autoppp

tmpfile=`mktemp /tmp/temp.XXXXXX`
cat $INSTROOTetc/mgetty+sendfax/login.config | while read md ; do
	case $md in
		*/AutoPPP/*a_ppp*)
                  mf=`echo $md | awk -F# '{print $2}'|awk -F 'a_ppp' '{print $1" - "$2}'`
                        
			echo "$mf" >> $tmpfile 
		;;
		*)
			echo "$md" >> $tmpfile
		;;
	esac
done
cp -f $INSTROOTetc/mgetty+sendfax/login.config $INSTROOTetc/mgetty+sendfax/login.config.old
cat $tmpfile > $INSTROOTetc/mgetty+sendfax/login.config
rm -f $tmpfile
   
#----------Now create or update the /etc/ppp/options.in file:
cp -f $INSTROOTetc/ppp/options $INSTROOTetc/ppp/options.out

dialog --infobox 'Creating $INSTROOTetc/ppp/options.in' 3 40

echo "-detach" > $INSTROOTetc/ppp/options.in
echo "modem" >> $INSTROOTetc/ppp/options.in
echo "lock" >> $INSTROOTetc/ppp/options.in
echo "crtscts" >> $INSTROOTetc/ppp/options.in
echo "asyncmap 0" >> $INSTROOTetc/ppp/options.in
echo "netmask 255.255.255.0" >> $INSTROOTetc/ppp/options.in
echo "proxyarp" >> $INSTROOTetc/ppp/options.in
echo "ms-dns $DNSSERV" >> $INSTROOTetc/ppp/options.in

# Now create the $INSTROOTetc/ppp/options.$COMPORT.in   
echo "# added by Dial in script by jthoma@md2.vsnl.net.in"\
	 > $INSTROOTetc/ppp/options.$COMPORT.in
echo "#<your server's hostname>:<The remote IP address>"\
	 >> $INSTROOTetc/ppp/options.$COMPORT.in
echo "$THISHOST:$REMOTEIP" >> $INSTROOTetc/ppp/options.$COMPORT.in

# Now append the pap-secrets 
if [ ! -e $INSTROOTetc/ppp/pap-secrets ] ; then
	echo "" > $INSTROOTetc/ppp/pap-secrets
fi
echo "# added by Dial in script by jthoma@md2.vsnl.net.in"\
		>> $INSTROOTetc/ppp/pap-secrets
echo "# Secrets for authentication using PAP" >> /etc/ppp/pap-secrets
echo "# client server secret IP addresses" >> /etc/ppp/pap-secrets
echo "* * '' $REMOTEIP" >> $INSTROOTetc/ppp/pap-secrets
   
#
#   Remember that mgetty will lock the modem for its own use. If you wish
#   to use the server for dialing out, you'll have to terminate the mgetty
#   process either manually or through some shell scripts.
#
#---------------------------------------------
#
dialog --infobox 'Creating on the fly switching scripts ...!' 3 45

echo "# Created by Dial in script by jthoma@md2.vsnl.net.in"\
		> /tmp/sdo
echo "# this configures the $instaltyp dial out setup for $COMPORT"\
		>> /tmp/sdo
echo "cp -f $INSTROOTetc/inittab.out $INSTROOTetc/inittab"\
		>> /tmp/sdo
echo "cp -f $INSTROOTetc/ppp/options.out $INSTROOTetc/ppp/options"\
		>> /tmp/sdo
echo "rm -f $INSTROOTetc/ppp/options.$COMPORT"\
		>> /tmp/sdo
echo "chmod -s $(which pppd)"\
		>> /tmp/sdo
echo "init q > /dev/null" >> /tmp/sdo
echo "echo ''" >> /tmp/sdo
echo "echo 'Ready to connect out ...!'" >> /tmp/sdo
echo "echo ''" >> /tmp/sdo
mv -f /tmp/sdo $INSTROOTbin/sdo
chmod +x $INSTROOTbin/sdo

#-----------------------------------------------
echo "# Created by Dial in script by jthoma@md2.vsnl.net.in"\
		> /tmp/sdi
echo "# this configures the $instaltyp dial in setup for $COMPORT"\
		>> /tmp/sdi
echo "cp -f $INSTROOTetc/inittab.in $INSTROOTetc/inittab"\
		>> /tmp/sdi
echo "cp -f $INSTROOTetc/ppp/options.in $INSTROOTetc/ppp/options"\
		>> /tmp/sdi
echo "cp -f $INSTROOTetc/ppp/options.$COMPORT.in $INSTROOTetc/ppp/options.$COMPORT"\
		>> /tmp/sdi
echo "chmod +s $(which pppd)"\
		>> /tmp/sdi
echo "init q > /dev/null" >> /tmp/sdi
echo "echo ''" >> /tmp/sdi
echo "echo 'Monitoring modem at $COMPORT ...!'" >> /tmp/sdi
echo "echo ''" >> /tmp/sdi
mv -f /tmp/sdi $INSTROOTbin/sdi
chmod +x $INSTROOTbin/sdi

echo "#!/bin/bash" > /tmp/server
echo "#" >> /tmp/server
echo "# This shell script takes care of starting and stopping" >> /tmp/server
echo "# and checking the server status" >> /tmp/server
echo "#" >> /tmp/server
echo "" >> /tmp/server
echo "# See how we were called." >> /tmp/server
echo 'case $1 in' >> /tmp/server
echo "	  dialin)" >> /tmp/server
echo "        # run sdi if it exists" >> /tmp/server
echo "	if [ -x $INSTROOTbin/sdi ] ; then " >> /tmp/server
echo '	echo "Setting up $instaltyp dialin :"' >> /tmp/server
echo "		$INSTROOTbin/sdi" >> /tmp/server
echo "	echo" >> /tmp/server
echo "	fi" >> /tmp/server
echo "      ;;" >> /tmp/server
echo "  dialout)" >> /tmp/server
echo "        # run sdo if it exists" >> /tmp/server
echo "	if [ -x /bin/sdo ] ; then " >> /tmp/server
echo '  echo "Setting up $instaltyp dial out :"' >> /tmp/server
echo "		$INSTROOTbin/sdo" >> /tmp/server
echo "	echo" >> /tmp/server
echo "	fi" >> /tmp/server
echo "        ;;" >> /tmp/server
echo "  status)" >> /tmp/server
echo '	occ=`grep 2345:respawn:/sbin/mgetty '"$INSTROOTetc"'/inittab|wc --lines`' >> /tmp/server
echo '	case $occ in' >> /tmp/server
echo "        	*0)" >> /tmp/server
echo "	 	   echo '$instaltyp Server in dial out mode' > /dev/tty0" >> /tmp/server
echo "	        ;;" >> /tmp/server
echo "	        *)" >> /tmp/server
echo "		   echo '$instaltyp Server in dialin mode' > /dev/tty0" >> /tmp/server
echo " 	        ;;" >> /tmp/server
echo "	esac" >> /tmp/server
echo "	;;" >> /tmp/server
echo "  *)" >> /tmp/server
echo "        echo 'Usage: $INSTROOTbin/server {dialin|dialout|status}'" >> /tmp/server
echo "        exit 1" >> /tmp/server
echo "esac" >> /tmp/server
echo "exit 0" >> /tmp/server

mv -f /tmp/server $INSTROOTbin/server
chmod +x $INSTROOTbin/server

#----------------------------------------------
#

dialog --title "Complete" \
	--backtitle "RedHat Linux Dial in Server Configuration script Version 2.0"\
        --msgbox "

OK, all done.

We have created the script server with options dialin|dialout|status
/bin for your convenience and the sdo and sdi scripts also have been
left for backward compatability hence before dialing out check the 
status of your server with server status and swtich the status using
server dialin|dialout

This script is based on the documentation Remote Logins at pcquest 
web site.  You will also find lots of current and past Linux 
articles on the web at http://www.pcquest.com/linux" 19 76


dialog --title "Complete" \
	--backtitle "RedHat Linux Dial in Server Configuration script Version 2.0"\
        --msgbox "$FINISHMSG" 8 50
